@@ -555,8 +555,9 @@ bool        _CalcNode::RecomputeMatrix  (long categID, long totalCategs, _Matrix
  
     if (isExplicitForm && bufferedOps) {
         _Matrix * bufferedExp = (_Matrix*)GetExplicitFormModel(map_global_to_local_category (categID))->Compute (0,nil, bufferedOps);
-        #ifdef _UBER_VERBOSE_MX_UPDATE_DUMP
+         #ifdef _UBER_VERBOSE_MX_UPDATE_DUMP
             fprintf (stderr, "[_CalcNode::RecomputeMatrix] Setting (buffered) category %ld/%ld for node %s\n", categID, totalCategs, GetName()->get_str());
+            ObjectToConsole(bufferedExp);
          #endif
         SetCompExp ((_Matrix*)bufferedExp->makeDynamic(), totalCategs>1?categID:-1);
         return false;
@@ -588,6 +589,9 @@ bool        _CalcNode::RecomputeMatrix  (long categID, long totalCategs, _Matrix
                     _Variable * model_var = LocateVar (ref_idx);
                     if (!model_var -> IsIndependent()) {
                         _Variable * param_var = LocateVar (var_idx);
+                        if (useGlobalUpdateFlag) {
+                            model_var->varFlags &= HY_DEP_V_COMPUTED_CLEAR & HY_DEP_V_MODIFIED_CLEAR & HY_DEP_V_INSPECTED_CLR;
+                        }
                         if (param_var->IsIndependent()) {
                             param_var->SetValue(param_var->Compute(),true,true,NULL);
                         }
