@@ -63,6 +63,7 @@ struct _TreeTopologyParseSettings {
         auto_convert_lengths = false;
         accept_user_lengths = true;
         ingore_user_inode_names = false;
+        auto_rename_nodes = true;
         parser_namespace = kEmptyString;
         parser_cache = nil;
     }
@@ -82,9 +83,11 @@ struct _TreeTopologyParseSettings {
   
     _String inode_prefix,
             parser_namespace;
+    
     bool    auto_convert_lengths,
             accept_user_lengths,
-            ingore_user_inode_names;
+            ingore_user_inode_names,
+            auto_rename_nodes;
   
     _AVLListX * parser_cache;
 };
