@@ -83,11 +83,13 @@ _SimpleList     freeSlots,
                 *deferSetFormula = nil;
 
 
-_AVLList       *deferClearConstraint = nil;
+_AVLList       *deferClearConstraint = nil,
+               *_keepTrackOfDepVars  = nil;
 
 bool            useGlobalUpdateFlag = false;
 
 
+
 _String         HalfOps (":<>=!&|");
 
 _Trie           UnOps;
